summaryrefslogtreecommitdiff
path: root/src/mongo/db/pipeline/pipeline.h
diff options
context:
space:
mode:
authorAnton Korshunov <anton.korshunov@mongodb.com>2019-11-28 13:46:53 +0000
committerevergreen <evergreen@mongodb.com>2019-11-28 13:46:53 +0000
commit995798094a170e1bbadb2659cfbe8b750f172b9d (patch)
tree3b0f753c379a766fe684438374d678fa8afe1ea2 /src/mongo/db/pipeline/pipeline.h
parent7c42573b96ecfa43fbf76aa01cd659ee00fc6103 (diff)
downloadmongo-995798094a170e1bbadb2659cfbe8b750f172b9d.tar.gz
SERVER-12335 indexKey $meta projection not populating fields
Diffstat (limited to 'src/mongo/db/pipeline/pipeline.h')
-rw-r--r--src/mongo/db/pipeline/pipeline.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/src/mongo/db/pipeline/pipeline.h b/src/mongo/db/pipeline/pipeline.h
index 39ba6372687..7c32a51c197 100644
--- a/src/mongo/db/pipeline/pipeline.h
+++ b/src/mongo/db/pipeline/pipeline.h
@@ -248,10 +248,10 @@ public:
std::vector<Value> writeExplainOps(ExplainOptions::Verbosity verbosity) const;
/**
* Returns the dependencies needed by this pipeline. 'metadataAvailable' should reflect what
* metadata is present on documents that are input to the front of the pipeline.
*/
- DepsTracker getDependencies(QueryMetadataBitSet metadataAvailable) const;
+ DepsTracker getDependencies(QueryMetadataBitSet unavailableMetadata) const;
const SourceContainer& getSources() const {
return _sources;
@@ -248,10 +248,10 @@ public:
std::vector<Value> writeExplainOps(ExplainOptions::Verbosity verbosity) const;
/**
- * Returns the dependencies needed by this pipeline. 'metadataAvailable' should reflect what
- * metadata is present on documents that are input to the front of the pipeline.
+ * Returns the dependencies needed by this pipeline. 'unavailableMetadata' should reflect what
+ * metadata is not present on documents that are input to the front of the pipeline.
*/